@@ -443,7 +443,9 @@ class TestPluginEtcdBase(_TestEtcdBase):
                      'interfaceName': 'tapDEADBEEF-12',
                      'ipNATs': [{'externalIP': '192.168.0.1',
                                  'internalIP': '10.65.0.2'}],
-                     'ipNetworks': ['10.65.0.2/32'],
+                     'ipNetworks': ['10.65.0.2/32',
+                                    '23.23.23.2/32'],
+                     'allowedIps': ['23.23.23.2/32'],
                      'ipv4Gateway': '10.65.0.1',
                      'mac': '00:11:22:33:44:55',
                      'node': 'felix-host-1',
@@ -475,6 +477,7 @@ class TestPluginEtcdBase(_TestEtcdBase):
             'spec': {'endpoint': 'FACEBEEF-1234-5678',
                      'interfaceName': 'tapFACEBEEF-12',
                      'ipNetworks': ['10.65.0.3/32'],
+                     'allowedIps': [],
                      'ipv4Gateway': '10.65.0.1',
                      'mac': '00:11:22:33:44:66',
                      'node': 'felix-host-1',
@@ -600,6 +603,7 @@ class TestPluginEtcdBase(_TestEtcdBase):
             'spec': {'endpoint': 'HELLO-1234-5678',
                      'interfaceName': 'tapHELLO-1234-',
                      'ipNetworks': ['2001:db8:a41:2::12/128'],
+                     'allowedIps': [],
                      'ipv6Gateway': '2001:db8:a41:2::1',
                      'mac': '00:11:22:33:44:66',
                      'node': 'felix-host-2',
